# ringer-business
This API provides comprehensive endpoints for the Ringer Business system.
It includes functionality for managing customer accounts, addresses, sites, 
phone numbers, payments, users, and other business resources.

Operations typically require authentication and appropriate permissions.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.5
- Package version: 1.0.0
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://docs.ringer.tel/support](https://docs.ringer.tel/support)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ringer_business
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ringer_business
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import ringer_business
from ringer_business.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.ringer.tel/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = ringer_business.Configuration(
    host = "https://api.ringer.tel/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with ringer_business.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ringer_business.AccountsApi(api_client)

    try:
        # Activate Current Account
        api_response = api_instance.activate_account()
        print("The response of AccountsApi->activate_account:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountsApi->activate_account: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.ringer.tel/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**activate_account**](docs/AccountsApi.md#activate_account) | **PATCH** /account | Activate Current Account
*AccountsApi* | [**close_account**](docs/AccountsApi.md#close_account) | **DELETE** /account | Close Current Account
*AccountsApi* | [**get_account_details**](docs/AccountsApi.md#get_account_details) | **GET** /account | Get Current Account Details
*AccountsApi* | [**update_account**](docs/AccountsApi.md#update_account) | **PUT** /account | Update Current Account Information
*AddressesApi* | [**update_account_address**](docs/AddressesApi.md#update_account_address) | **PUT** /addresses/{addressId} | Update an Address
*AuthenticationApi* | [**fetch_access_token**](docs/AuthenticationApi.md#fetch_access_token) | **POST** /auth/token | Obtain an OAuth 2.0 Access Token
*AuthenticationApi* | [**revoke_access_token**](docs/AuthenticationApi.md#revoke_access_token) | **POST** /auth/revoke | Revoke an OAuth 2.0 Token
*CallRecordsApi* | [**list_call_records**](docs/CallRecordsApi.md#list_call_records) | **GET** /call-records | List Call Records
*ConfirmationApi* | [**confirm_account**](docs/ConfirmationApi.md#confirm_account) | **POST** /confirmation | Confirm a User Account
*CountryCodesApi* | [**list_available_country_codes**](docs/CountryCodesApi.md#list_available_country_codes) | **GET** /country-codes | List Available Country Codes
*CreditCardsApi* | [**create_credit_card**](docs/CreditCardsApi.md#create_credit_card) | **POST** /credit-cards | Add a New Credit Card
*CreditCardsApi* | [**list_credit_cards**](docs/CreditCardsApi.md#list_credit_cards) | **GET** /credit-cards | List Credit Cards
*ItemsApi* | [**update_item_by_id**](docs/ItemsApi.md#update_item_by_id) | **PUT** /items/{itemId} | Update Item Details
*PackagesApi* | [**get_package_by_id**](docs/PackagesApi.md#get_package_by_id) | **GET** /packages/{packageId} | Get Package Details
*PackagesApi* | [**list_packages**](docs/PackagesApi.md#list_packages) | **GET** /packages | List Packages
*PaymentsApi* | [**create_payment**](docs/PaymentsApi.md#create_payment) | **POST** /payments | Create a Payment
*PaymentsApi* | [**list_payments**](docs/PaymentsApi.md#list_payments) | **GET** /payments | List Payments
*PlansApi* | [**get_plan_by_id**](docs/PlansApi.md#get_plan_by_id) | **GET** /plans/{planId} | Get Plan Details
*PlansApi* | [**list_account_plans**](docs/PlansApi.md#list_account_plans) | **GET** /plans | List Current Account Plan(s)
*SignUpApi* | [**sign_up_customer**](docs/SignUpApi.md#sign_up_customer) | **POST** /sign-up | Register a new Customer Account
*SiteFeaturesCallBlockingApi* | [**create_site_call_block**](docs/SiteFeaturesCallBlockingApi.md#create_site_call_block) | **POST** /sites/{siteId}/call-blocks | Create a Call Block Rule
*SiteFeaturesCallBlockingApi* | [**delete_site_call_block_by_id**](docs/SiteFeaturesCallBlockingApi.md#delete_site_call_block_by_id) | **DELETE** /sites/{siteId}/call-blocks/{callBlockId} | Delete a Call Block Rule
*SiteFeaturesCallBlockingApi* | [**get_site_call_block_by_id**](docs/SiteFeaturesCallBlockingApi.md#get_site_call_block_by_id) | **GET** /sites/{siteId}/call-blocks/{callBlockId} | Get Call Block Rule Details
*SiteFeaturesCallBlockingApi* | [**list_site_call_blocks**](docs/SiteFeaturesCallBlockingApi.md#list_site_call_blocks) | **GET** /sites/{siteId}/call-blocks | List Call Block Rules for a Site
*SiteFeaturesCallBlockingApi* | [**update_site_call_block_by_id**](docs/SiteFeaturesCallBlockingApi.md#update_site_call_block_by_id) | **PUT** /sites/{siteId}/call-blocks/{callBlockId} | Update Call Block Rule
*SiteFeaturesConferenceRoomsApi* | [**create_site_conference_room**](docs/SiteFeaturesConferenceRoomsApi.md#create_site_conference_room) | **POST** /sites/{siteId}/conference-rooms | Create a Conference Room for a Site
*SiteFeaturesConferenceRoomsApi* | [**delete_site_conference_room_by_id**](docs/SiteFeaturesConferenceRoomsApi.md#delete_site_conference_room_by_id) | **DELETE** /sites/{siteId}/conference-rooms/{conferenceRoomId} | Delete a Conference Room
*SiteFeaturesConferenceRoomsApi* | [**get_site_conference_room_by_id**](docs/SiteFeaturesConferenceRoomsApi.md#get_site_conference_room_by_id) | **GET** /sites/{siteId}/conference-rooms/{conferenceRoomId} | Get Conference Room Details
*SiteFeaturesConferenceRoomsApi* | [**list_site_available_conference_rooms**](docs/SiteFeaturesConferenceRoomsApi.md#list_site_available_conference_rooms) | **GET** /sites/{siteId}/conference-rooms/available | List Available Conference Rooms for a Site/User
*SiteFeaturesConferenceRoomsApi* | [**list_site_conference_rooms**](docs/SiteFeaturesConferenceRoomsApi.md#list_site_conference_rooms) | **GET** /sites/{siteId}/conference-rooms | List Conference Rooms for a Site
*SiteFeaturesConferenceRoomsApi* | [**transfer_conference_room_to_new_site**](docs/SiteFeaturesConferenceRoomsApi.md#transfer_conference_room_to_new_site) | **POST** /sites/{siteId}/conference-rooms/{conferenceRoomId}/transfer | Transfer Conference Room to Another Site
*SiteFeaturesConferenceRoomsApi* | [**update_site_conference_room_by_id**](docs/SiteFeaturesConferenceRoomsApi.md#update_site_conference_room_by_id) | **PUT** /sites/{siteId}/conference-rooms/{conferenceRoomId} | Update Conference Room Configuration
*SiteFeaturesConferenceRoomsApi* | [**upload_site_conference_room_audio**](docs/SiteFeaturesConferenceRoomsApi.md#upload_site_conference_room_audio) | **PATCH** /sites/{siteId}/conference-rooms/{conferenceRoomId}/upload | Upload Conference Room Audio Files
*SiteFeaturesDevicesApi* | [**create_site_device**](docs/SiteFeaturesDevicesApi.md#create_site_device) | **POST** /sites/{siteId}/devices | Create a Device for a Site
*SiteFeaturesDevicesApi* | [**delete_site_device_by_id**](docs/SiteFeaturesDevicesApi.md#delete_site_device_by_id) | **DELETE** /sites/{siteId}/devices/{deviceId} | Delete a Device
*SiteFeaturesDevicesApi* | [**get_site_device_by_id**](docs/SiteFeaturesDevicesApi.md#get_site_device_by_id) | **GET** /sites/{siteId}/devices/{deviceId} | Get Device Details
*SiteFeaturesDevicesApi* | [**list_site_available_devices**](docs/SiteFeaturesDevicesApi.md#list_site_available_devices) | **GET** /sites/{siteId}/devices/available | List Available Devices for a Site/User
*SiteFeaturesDevicesApi* | [**list_site_devices**](docs/SiteFeaturesDevicesApi.md#list_site_devices) | **GET** /sites/{siteId}/devices | List Devices for a Site
*SiteFeaturesDevicesApi* | [**regenerate_site_device_password**](docs/SiteFeaturesDevicesApi.md#regenerate_site_device_password) | **PATCH** /sites/{siteId}/devices/{deviceId}/regenerate-password | Regenerate Device SIP Password
*SiteFeaturesDevicesApi* | [**transfer_device_to_new_site**](docs/SiteFeaturesDevicesApi.md#transfer_device_to_new_site) | **POST** /sites/{siteId}/devices/{deviceId}/transfer | Transfer Device to Another Site
*SiteFeaturesDevicesApi* | [**update_site_device_by_id**](docs/SiteFeaturesDevicesApi.md#update_site_device_by_id) | **PUT** /sites/{siteId}/devices/{deviceId} | Update Device Configuration
*SiteFeaturesE911Api* | [**delete_site_e911_record_by_id**](docs/SiteFeaturesE911Api.md#delete_site_e911_record_by_id) | **DELETE** /sites/{siteId}/e911s/{e911Id} | Delete E911 Record
*SiteFeaturesE911Api* | [**get_site_e911_record_by_id**](docs/SiteFeaturesE911Api.md#get_site_e911_record_by_id) | **GET** /sites/{siteId}/e911s/{e911Id} | Get E911 Record Details
*SiteFeaturesE911Api* | [**list_site_e911_records**](docs/SiteFeaturesE911Api.md#list_site_e911_records) | **GET** /sites/{siteId}/e911s | List E911 Records for a Site
*SiteFeaturesE911Api* | [**update_site_e911_record_by_id**](docs/SiteFeaturesE911Api.md#update_site_e911_record_by_id) | **PUT** /sites/{siteId}/e911s/{e911Id} | Update E911 Record
*SiteFeaturesExtensionsApi* | [**create_site_extension**](docs/SiteFeaturesExtensionsApi.md#create_site_extension) | **POST** /sites/{siteId}/extensions | Create Extension for a Site
*SiteFeaturesExtensionsApi* | [**delete_site_extension_by_id**](docs/SiteFeaturesExtensionsApi.md#delete_site_extension_by_id) | **DELETE** /sites/{siteId}/extensions/{extensionId} | Delete an Extension
*SiteFeaturesExtensionsApi* | [**get_site_extension_by_id**](docs/SiteFeaturesExtensionsApi.md#get_site_extension_by_id) | **GET** /sites/{siteId}/extensions/{extensionId} | Get Extension Details
*SiteFeaturesExtensionsApi* | [**list_site_available_extensions**](docs/SiteFeaturesExtensionsApi.md#list_site_available_extensions) | **GET** /sites/{siteId}/extensions/available | List Available Extensions for a Site/User
*SiteFeaturesExtensionsApi* | [**list_site_extensions**](docs/SiteFeaturesExtensionsApi.md#list_site_extensions) | **GET** /sites/{siteId}/extensions | List Extensions for a Site
*SiteFeaturesExtensionsApi* | [**transfer_site_extension**](docs/SiteFeaturesExtensionsApi.md#transfer_site_extension) | **POST** /sites/{siteId}/extensions/{extensionId}/transfer | Transfer Extension to Another Site
*SiteFeaturesExtensionsApi* | [**update_site_extension_by_id**](docs/SiteFeaturesExtensionsApi.md#update_site_extension_by_id) | **PUT** /sites/{siteId}/extensions/{extensionId} | Update Extension Configuration
*SiteFeaturesFaxMachinesApi* | [**create_site_fax_machine**](docs/SiteFeaturesFaxMachinesApi.md#create_site_fax_machine) | **POST** /sites/{siteId}/fax-machines | Create a Fax Machine for a Site
*SiteFeaturesFaxMachinesApi* | [**delete_site_fax_machine_by_id**](docs/SiteFeaturesFaxMachinesApi.md#delete_site_fax_machine_by_id) | **DELETE** /sites/{siteId}/fax-machines/{faxMachineId} | Delete a Fax Machine Configuration
*SiteFeaturesFaxMachinesApi* | [**get_site_fax_machine_by_id**](docs/SiteFeaturesFaxMachinesApi.md#get_site_fax_machine_by_id) | **GET** /sites/{siteId}/fax-machines/{faxMachineId} | Get Fax Machine Details
*SiteFeaturesFaxMachinesApi* | [**list_site_available_fax_machines**](docs/SiteFeaturesFaxMachinesApi.md#list_site_available_fax_machines) | **GET** /sites/{siteId}/fax-machines/available | List Available Fax Machines for a Site/User
*SiteFeaturesFaxMachinesApi* | [**list_site_fax_machines**](docs/SiteFeaturesFaxMachinesApi.md#list_site_fax_machines) | **GET** /sites/{siteId}/fax-machines | List Fax Machines for a Site
*SiteFeaturesFaxMachinesApi* | [**transfer_fax_machine_to_new_site**](docs/SiteFeaturesFaxMachinesApi.md#transfer_fax_machine_to_new_site) | **POST** /sites/{siteId}/fax-machines/{faxMachineId}/transfer | Transfer Fax Machine to Another Site
*SiteFeaturesFaxMachinesApi* | [**update_site_fax_machine_by_id**](docs/SiteFeaturesFaxMachinesApi.md#update_site_fax_machine_by_id) | **PUT** /sites/{siteId}/fax-machines/{faxMachineId} | Update Fax Machine Configuration
*SiteFeaturesForwardsApi* | [**create_site_forward**](docs/SiteFeaturesForwardsApi.md#create_site_forward) | **POST** /sites/{siteId}/forwards | Create Forward for a Site
*SiteFeaturesForwardsApi* | [**delete_site_forward_by_id**](docs/SiteFeaturesForwardsApi.md#delete_site_forward_by_id) | **DELETE** /sites/{siteId}/forwards/{forwardId} | Delete Site Forward
*SiteFeaturesForwardsApi* | [**get_site_forward_by_id**](docs/SiteFeaturesForwardsApi.md#get_site_forward_by_id) | **GET** /sites/{siteId}/forwards/{forwardId} | Get Site Forward Details
*SiteFeaturesForwardsApi* | [**list_site_available_forwards**](docs/SiteFeaturesForwardsApi.md#list_site_available_forwards) | **GET** /sites/{siteId}/forwards/available | List Available Forwards for a Site/User
*SiteFeaturesForwardsApi* | [**list_site_forwards**](docs/SiteFeaturesForwardsApi.md#list_site_forwards) | **GET** /sites/{siteId}/forwards | List Forwards for a Site
*SiteFeaturesForwardsApi* | [**transfer_site_forward**](docs/SiteFeaturesForwardsApi.md#transfer_site_forward) | **POST** /sites/{siteId}/forwards/{forwardId}/transfer | Transfer Site Forward
*SiteFeaturesForwardsApi* | [**update_site_forward_by_id**](docs/SiteFeaturesForwardsApi.md#update_site_forward_by_id) | **PUT** /sites/{siteId}/forwards/{forwardId} | Update Site Forward
*SiteFeaturesLocationsApi* | [**create_site_location**](docs/SiteFeaturesLocationsApi.md#create_site_location) | **POST** /sites/{siteId}/locations | Create a Location for a Site
*SiteFeaturesLocationsApi* | [**delete_site_location_by_id**](docs/SiteFeaturesLocationsApi.md#delete_site_location_by_id) | **DELETE** /sites/{siteId}/locations/{locationId} | Delete a Location
*SiteFeaturesLocationsApi* | [**get_site_location_by_id**](docs/SiteFeaturesLocationsApi.md#get_site_location_by_id) | **GET** /sites/{siteId}/locations/{locationId} | Get Location Details
*SiteFeaturesLocationsApi* | [**list_site_locations**](docs/SiteFeaturesLocationsApi.md#list_site_locations) | **GET** /sites/{siteId}/locations | List Locations for a Site
*SiteFeaturesLocationsApi* | [**update_site_location_by_id**](docs/SiteFeaturesLocationsApi.md#update_site_location_by_id) | **PUT** /sites/{siteId}/locations/{locationId} | Update Location Details
*SiteFeaturesMenusApi* | [**create_site_menu**](docs/SiteFeaturesMenusApi.md#create_site_menu) | **POST** /sites/{siteId}/menus | Create Menu for a Site
*SiteFeaturesMenusApi* | [**delete_site_menu_by_id**](docs/SiteFeaturesMenusApi.md#delete_site_menu_by_id) | **DELETE** /sites/{siteId}/menus/{menuId} | Delete Menu
*SiteFeaturesMenusApi* | [**get_site_menu_by_id**](docs/SiteFeaturesMenusApi.md#get_site_menu_by_id) | **GET** /sites/{siteId}/menus/{menuId} | Get Menu Details
*SiteFeaturesMenusApi* | [**list_site_menus**](docs/SiteFeaturesMenusApi.md#list_site_menus) | **GET** /sites/{siteId}/menus | List Menus for a Site
*SiteFeaturesMenusApi* | [**transfer_site_menu**](docs/SiteFeaturesMenusApi.md#transfer_site_menu) | **POST** /sites/{siteId}/menus/{menuId}/transfer | Transfer Menu to Another Site
*SiteFeaturesMenusApi* | [**update_site_menu_by_id**](docs/SiteFeaturesMenusApi.md#update_site_menu_by_id) | **PUT** /sites/{siteId}/menus/{menuId} | Update Menu Configuration
*SiteFeaturesMenusApi* | [**upload_site_menu_greeting**](docs/SiteFeaturesMenusApi.md#upload_site_menu_greeting) | **PATCH** /sites/{siteId}/menus/{menuId}/upload | Upload Menu Greeting
*SiteFeaturesPhoneNumbersApi* | [**assign_site_phone_number**](docs/SiteFeaturesPhoneNumbersApi.md#assign_site_phone_number) | **POST** /sites/{siteId}/phone-numbers | Assign Phone Number to Site
*SiteFeaturesPhoneNumbersApi* | [**delete_site_phone_number_by_id**](docs/SiteFeaturesPhoneNumbersApi.md#delete_site_phone_number_by_id) | **DELETE** /sites/{siteId}/phone-numbers/{phoneNumberId} | Unassign/Delete Phone Number from Site
*SiteFeaturesPhoneNumbersApi* | [**get_site_phone_number_by_id**](docs/SiteFeaturesPhoneNumbersApi.md#get_site_phone_number_by_id) | **GET** /sites/{siteId}/phone-numbers/{phoneNumberId} | Get Phone Number Details
*SiteFeaturesPhoneNumbersApi* | [**list_site_available_phone_numbers**](docs/SiteFeaturesPhoneNumbersApi.md#list_site_available_phone_numbers) | **GET** /sites/{siteId}/phone-numbers/available | List Available Phone Numbers for a Site
*SiteFeaturesPhoneNumbersApi* | [**list_site_phone_numbers**](docs/SiteFeaturesPhoneNumbersApi.md#list_site_phone_numbers) | **GET** /sites/{siteId}/phone-numbers | List Phone Numbers for a Site
*SiteFeaturesPhoneNumbersApi* | [**transfer_site_phone_number**](docs/SiteFeaturesPhoneNumbersApi.md#transfer_site_phone_number) | **POST** /sites/{siteId}/phone-numbers/{phoneNumberId}/transfer | Transfer Phone Number to Another Site
*SiteFeaturesPhoneNumbersApi* | [**update_site_phone_number_by_id**](docs/SiteFeaturesPhoneNumbersApi.md#update_site_phone_number_by_id) | **PUT** /sites/{siteId}/phone-numbers/{phoneNumberId} | Update Phone Number Configuration
*SiteFeaturesRingGroupsApi* | [**create_site_ring_group**](docs/SiteFeaturesRingGroupsApi.md#create_site_ring_group) | **POST** /sites/{siteId}/ring-groups | Create Ring Group for a Site
*SiteFeaturesRingGroupsApi* | [**delete_site_ring_group_by_id**](docs/SiteFeaturesRingGroupsApi.md#delete_site_ring_group_by_id) | **DELETE** /sites/{siteId}/ring-groups/{ringGroupId} | Delete Ring Group
*SiteFeaturesRingGroupsApi* | [**get_site_ring_group_by_id**](docs/SiteFeaturesRingGroupsApi.md#get_site_ring_group_by_id) | **GET** /sites/{siteId}/ring-groups/{ringGroupId} | Get Ring Group Details
*SiteFeaturesRingGroupsApi* | [**list_site_ring_groups**](docs/SiteFeaturesRingGroupsApi.md#list_site_ring_groups) | **GET** /sites/{siteId}/ring-groups | List Ring Groups for a Site
*SiteFeaturesRingGroupsApi* | [**transfer_site_ring_group**](docs/SiteFeaturesRingGroupsApi.md#transfer_site_ring_group) | **POST** /sites/{siteId}/ring-groups/{ringGroupId}/transfer | Transfer Ring Group to Another Site
*SiteFeaturesRingGroupsApi* | [**update_site_ring_group_by_id**](docs/SiteFeaturesRingGroupsApi.md#update_site_ring_group_by_id) | **PUT** /sites/{siteId}/ring-groups/{ringGroupId} | Update Ring Group Configuration
*SiteFeaturesSIPTrunksApi* | [**create_site_sip_trunk**](docs/SiteFeaturesSIPTrunksApi.md#create_site_sip_trunk) | **POST** /sites/{siteId}/sip-trunks | Create SIP Trunk for a Site
*SiteFeaturesSIPTrunksApi* | [**delete_site_sip_trunk_by_id**](docs/SiteFeaturesSIPTrunksApi.md#delete_site_sip_trunk_by_id) | **DELETE** /sites/{siteId}/sip-trunks/{sipTrunkId} | Delete a SIP Trunk
*SiteFeaturesSIPTrunksApi* | [**get_site_sip_trunk_by_id**](docs/SiteFeaturesSIPTrunksApi.md#get_site_sip_trunk_by_id) | **GET** /sites/{siteId}/sip-trunks/{sipTrunkId} | Get SIP Trunk Details
*SiteFeaturesSIPTrunksApi* | [**list_site_sip_trunks**](docs/SiteFeaturesSIPTrunksApi.md#list_site_sip_trunks) | **GET** /sites/{siteId}/sip-trunks | List SIP Trunks for a Site
*SiteFeaturesSIPTrunksApi* | [**regenerate_site_sip_trunk_password**](docs/SiteFeaturesSIPTrunksApi.md#regenerate_site_sip_trunk_password) | **PATCH** /sites/{siteId}/sip-trunks/{sipTrunkId}/regenerate-password | Regenerate SIP Trunk Password
*SiteFeaturesSIPTrunksApi* | [**transfer_sip_trunk**](docs/SiteFeaturesSIPTrunksApi.md#transfer_sip_trunk) | **POST** /sites/{siteId}/sip-trunks/{sipTrunkId}/transfer | Transfer SIP Trunk
*SiteFeaturesSIPTrunksApi* | [**update_site_sip_trunk_by_id**](docs/SiteFeaturesSIPTrunksApi.md#update_site_sip_trunk_by_id) | **PUT** /sites/{siteId}/sip-trunks/{sipTrunkId} | Update SIP Trunk
*SiteFeaturesSchedulesApi* | [**create_site_schedule**](docs/SiteFeaturesSchedulesApi.md#create_site_schedule) | **POST** /sites/{siteId}/schedules | Create Schedule for a Site
*SiteFeaturesSchedulesApi* | [**delete_site_schedule_by_id**](docs/SiteFeaturesSchedulesApi.md#delete_site_schedule_by_id) | **DELETE** /sites/{siteId}/schedules/{scheduleId} | Delete a Schedule
*SiteFeaturesSchedulesApi* | [**get_site_schedule_by_id**](docs/SiteFeaturesSchedulesApi.md#get_site_schedule_by_id) | **GET** /sites/{siteId}/schedules/{scheduleId} | Get Schedule Details
*SiteFeaturesSchedulesApi* | [**list_site_available_schedules**](docs/SiteFeaturesSchedulesApi.md#list_site_available_schedules) | **GET** /sites/{siteId}/schedules/available | List Available Schedules for a Site
*SiteFeaturesSchedulesApi* | [**list_site_schedules**](docs/SiteFeaturesSchedulesApi.md#list_site_schedules) | **GET** /sites/{siteId}/schedules | List Schedules for a Site
*SiteFeaturesSchedulesApi* | [**transfer_site_schedule**](docs/SiteFeaturesSchedulesApi.md#transfer_site_schedule) | **POST** /sites/{siteId}/schedules/{scheduleId}/transfer | Transfer Schedule to Another Site
*SiteFeaturesSchedulesApi* | [**update_site_schedule_by_id**](docs/SiteFeaturesSchedulesApi.md#update_site_schedule_by_id) | **PUT** /sites/{siteId}/schedules/{scheduleId} | Update Schedule
*SiteFeaturesSeatsApi* | [**create_site_seat**](docs/SiteFeaturesSeatsApi.md#create_site_seat) | **POST** /sites/{siteId}/seats | Create Seat for a Site
*SiteFeaturesSeatsApi* | [**delete_site_seat_by_id**](docs/SiteFeaturesSeatsApi.md#delete_site_seat_by_id) | **DELETE** /sites/{siteId}/seats/{seatId} | Delete Seat
*SiteFeaturesSeatsApi* | [**get_site_seat_by_id**](docs/SiteFeaturesSeatsApi.md#get_site_seat_by_id) | **GET** /sites/{siteId}/seats/{seatId} | Get Seat Details
*SiteFeaturesSeatsApi* | [**list_site_seats**](docs/SiteFeaturesSeatsApi.md#list_site_seats) | **GET** /sites/{siteId}/seats | List Seats for a Site
*SiteFeaturesSeatsApi* | [**transfer_site_seat**](docs/SiteFeaturesSeatsApi.md#transfer_site_seat) | **POST** /sites/{siteId}/seats/{seatId}/transfer | Transfer Seat to Another Site
*SiteFeaturesSeatsApi* | [**update_site_seat_by_id**](docs/SiteFeaturesSeatsApi.md#update_site_seat_by_id) | **PUT** /sites/{siteId}/seats/{seatId} | Update Seat Information
*SiteFeaturesVoicemailBoxesApi* | [**create_site_voicemail_box**](docs/SiteFeaturesVoicemailBoxesApi.md#create_site_voicemail_box) | **POST** /sites/{siteId}/voice-mail-boxes | Create Voicemail Box for a Site
*SiteFeaturesVoicemailBoxesApi* | [**list_site_available_voicemail_boxes**](docs/SiteFeaturesVoicemailBoxesApi.md#list_site_available_voicemail_boxes) | **GET** /sites/{siteId}/voice-mail-boxes/available | List Available Voicemail Boxes for a Site
*SiteFeaturesVoicemailBoxesApi* | [**list_site_voicemail_boxes**](docs/SiteFeaturesVoicemailBoxesApi.md#list_site_voicemail_boxes) | **GET** /sites/{siteId}/voice-mail-boxes | List Voicemail Boxes for a Site
*SitesApi* | [**create_site**](docs/SitesApi.md#create_site) | **POST** /sites | Create a New Site
*SitesApi* | [**delete_site_by_id**](docs/SitesApi.md#delete_site_by_id) | **DELETE** /sites/{siteId} | Delete a Site
*SitesApi* | [**get_site_by_id**](docs/SitesApi.md#get_site_by_id) | **GET** /sites/{siteId} | Get Site Details
*SitesApi* | [**list_sites**](docs/SitesApi.md#list_sites) | **GET** /sites | List Sites
*SitesApi* | [**update_site_by_id**](docs/SitesApi.md#update_site_by_id) | **PUT** /sites/{siteId} | Update Site Configuration
*StatementsApi* | [**get_statement_by_id**](docs/StatementsApi.md#get_statement_by_id) | **GET** /statements/{statementId} | Get Statement Details
*StatementsApi* | [**list_statements**](docs/StatementsApi.md#list_statements) | **GET** /statements | List Account Statements
*TemplatesApi* | [**create_template**](docs/TemplatesApi.md#create_template) | **POST** /templates | Create a New Template
*TemplatesApi* | [**delete_template_by_id**](docs/TemplatesApi.md#delete_template_by_id) | **DELETE** /templates/{templateId} | Delete a Template
*TemplatesApi* | [**get_template_by_id**](docs/TemplatesApi.md#get_template_by_id) | **GET** /templates/{templateId} | Get Template Details
*TemplatesApi* | [**list_templates**](docs/TemplatesApi.md#list_templates) | **GET** /templates | List Templates
*TemplatesApi* | [**update_template_by_id**](docs/TemplatesApi.md#update_template_by_id) | **PUT** /templates/{templateId} | Update an Existing Template
*ThinClientsApi* | [**list_available_thin_clients**](docs/ThinClientsApi.md#list_available_thin_clients) | **GET** /thin-clients | List Available Thin Clients
*TimezonesApi* | [**list_available_timezones**](docs/TimezonesApi.md#list_available_timezones) | **GET** /timezones | List Available Timezones
*UsersApi* | [**add_user**](docs/UsersApi.md#add_user) | **POST** /users | Add a New User
*UsersApi* | [**delete_user_by_id**](docs/UsersApi.md#delete_user_by_id) | **DELETE** /users/{userId} | Delete User
*UsersApi* | [**get_user_by_id**](docs/UsersApi.md#get_user_by_id) | **GET** /users/{userId} | Get User Details
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /users | List Users
*UsersApi* | [**update_user_by_id**](docs/UsersApi.md#update_user_by_id) | **PUT** /users/{userId} | Update User Information


## Documentation For Models

 - [AccountResponse](docs/AccountResponse.md)
 - [AccountUpdateRequest](docs/AccountUpdateRequest.md)
 - [AddressCore](docs/AddressCore.md)
 - [AddressRegistered](docs/AddressRegistered.md)
 - [AddressResponse](docs/AddressResponse.md)
 - [AddressUpdateRequest](docs/AddressUpdateRequest.md)
 - [AddressUserProvided](docs/AddressUserProvided.md)
 - [AvailableComponentsSchemasError](docs/AvailableComponentsSchemasError.md)
 - [AvailableForward](docs/AvailableForward.md)
 - [AvailableForwardListResponse](docs/AvailableForwardListResponse.md)
 - [AvailablePhoneNumber](docs/AvailablePhoneNumber.md)
 - [AvailablePhoneNumberListResponse](docs/AvailablePhoneNumberListResponse.md)
 - [CallBlockAttributes](docs/CallBlockAttributes.md)
 - [CallBlockComponentsSchemasError](docs/CallBlockComponentsSchemasError.md)
 - [CallBlockComponentsSchemasErrorDetailsInner](docs/CallBlockComponentsSchemasErrorDetailsInner.md)
 - [CallBlockCore](docs/CallBlockCore.md)
 - [CallBlockCreateRequest](docs/CallBlockCreateRequest.md)
 - [CallBlockCreateRequestData](docs/CallBlockCreateRequestData.md)
 - [CallBlockListResponse](docs/CallBlockListResponse.md)
 - [CallBlockResponse](docs/CallBlockResponse.md)
 - [CallBlockUpdateRequest](docs/CallBlockUpdateRequest.md)
 - [CallBlockUpdateRequestData](docs/CallBlockUpdateRequestData.md)
 - [CallBlockUpdateRequestDataAttributes](docs/CallBlockUpdateRequestDataAttributes.md)
 - [CallRecord](docs/CallRecord.md)
 - [CallRecordError](docs/CallRecordError.md)
 - [CallRecordItemSummary](docs/CallRecordItemSummary.md)
 - [CallRecordListResponse](docs/CallRecordListResponse.md)
 - [CallRecordsComponentsSchemasError](docs/CallRecordsComponentsSchemasError.md)
 - [CallRecordsComponentsSchemasErrorDetailsInner](docs/CallRecordsComponentsSchemasErrorDetailsInner.md)
 - [ComponentsSchemasError](docs/ComponentsSchemasError.md)
 - [ComponentsSchemasLink](docs/ComponentsSchemasLink.md)
 - [ConferenceRoomCore](docs/ConferenceRoomCore.md)
 - [ConferenceRoomListResponse](docs/ConferenceRoomListResponse.md)
 - [ConferenceRoomResponse](docs/ConferenceRoomResponse.md)
 - [ConfirmationComponentsSchemasError](docs/ConfirmationComponentsSchemasError.md)
 - [ConfirmationRequest](docs/ConfirmationRequest.md)
 - [ConfirmationResponse](docs/ConfirmationResponse.md)
 - [CountryCode](docs/CountryCode.md)
 - [CountryCodeListResponse](docs/CountryCodeListResponse.md)
 - [CountryCodesComponentsSchemasError](docs/CountryCodesComponentsSchemasError.md)
 - [CreditCardCore](docs/CreditCardCore.md)
 - [CreditCardCreateRequest](docs/CreditCardCreateRequest.md)
 - [CreditCardResponse](docs/CreditCardResponse.md)
 - [CreditCardsComponentsSchemasError](docs/CreditCardsComponentsSchemasError.md)
 - [CustomerRegistrationRequest](docs/CustomerRegistrationRequest.md)
 - [CustomerRegistrationResponse](docs/CustomerRegistrationResponse.md)
 - [DeviceComponentsSchemasError](docs/DeviceComponentsSchemasError.md)
 - [DeviceCore](docs/DeviceCore.md)
 - [DeviceCreateRequest](docs/DeviceCreateRequest.md)
 - [DeviceListResponse](docs/DeviceListResponse.md)
 - [DeviceResponse](docs/DeviceResponse.md)
 - [DeviceResponseAllOfFailOverDestination](docs/DeviceResponseAllOfFailOverDestination.md)
 - [DeviceResponseWithPassword](docs/DeviceResponseWithPassword.md)
 - [DeviceUpdateRequest](docs/DeviceUpdateRequest.md)
 - [E911Core](docs/E911Core.md)
 - [E911ListResponse](docs/E911ListResponse.md)
 - [E911Response](docs/E911Response.md)
 - [E911UpdateRequest](docs/E911UpdateRequest.md)
 - [Error](docs/Error.md)
 - [ErrorDetailsInner](docs/ErrorDetailsInner.md)
 - [ExtensionComponentsSchemasError](docs/ExtensionComponentsSchemasError.md)
 - [ExtensionCore](docs/ExtensionCore.md)
 - [ExtensionCreateRequest](docs/ExtensionCreateRequest.md)
 - [ExtensionListResponse](docs/ExtensionListResponse.md)
 - [ExtensionResponse](docs/ExtensionResponse.md)
 - [ExtensionUpdateRequest](docs/ExtensionUpdateRequest.md)
 - [FaxMachineCore](docs/FaxMachineCore.md)
 - [FaxMachineCreateRequest](docs/FaxMachineCreateRequest.md)
 - [FaxMachineListResponse](docs/FaxMachineListResponse.md)
 - [FaxMachineResponse](docs/FaxMachineResponse.md)
 - [FaxMachineUpdateRequest](docs/FaxMachineUpdateRequest.md)
 - [ForwardCore](docs/ForwardCore.md)
 - [ForwardCreateRequest](docs/ForwardCreateRequest.md)
 - [ForwardResponse](docs/ForwardResponse.md)
 - [ForwardUpdateRequest](docs/ForwardUpdateRequest.md)
 - [IndexComponentsSchemasError](docs/IndexComponentsSchemasError.md)
 - [IndexComponentsSchemasError2](docs/IndexComponentsSchemasError2.md)
 - [IndexComponentsSchemasLink](docs/IndexComponentsSchemasLink.md)
 - [ItemCore](docs/ItemCore.md)
 - [ItemResponse](docs/ItemResponse.md)
 - [ItemUpdateRequest](docs/ItemUpdateRequest.md)
 - [ItemsComponentsSchemasError](docs/ItemsComponentsSchemasError.md)
 - [Link](docs/Link.md)
 - [LocationCore](docs/LocationCore.md)
 - [LocationCreateRequest](docs/LocationCreateRequest.md)
 - [LocationResponse](docs/LocationResponse.md)
 - [LocationUpdateRequest](docs/LocationUpdateRequest.md)
 - [MenuCore](docs/MenuCore.md)
 - [MenuResponse](docs/MenuResponse.md)
 - [OauthComponentsSchemasError](docs/OauthComponentsSchemasError.md)
 - [PackageCore](docs/PackageCore.md)
 - [PackageFeature](docs/PackageFeature.md)
 - [PackageResponse](docs/PackageResponse.md)
 - [PackagesComponentsSchemasError](docs/PackagesComponentsSchemasError.md)
 - [PaginatedCreditCardListResponse](docs/PaginatedCreditCardListResponse.md)
 - [PaginatedExtensionListResponse](docs/PaginatedExtensionListResponse.md)
 - [PaginatedForwardListResponse](docs/PaginatedForwardListResponse.md)
 - [PaginatedLocationListResponse](docs/PaginatedLocationListResponse.md)
 - [PaginatedMenuListResponse](docs/PaginatedMenuListResponse.md)
 - [PaginatedPackageListResponse](docs/PaginatedPackageListResponse.md)
 - [PaginatedPhoneNumberListResponse](docs/PaginatedPhoneNumberListResponse.md)
 - [PaginatedPlanListResponse](docs/PaginatedPlanListResponse.md)
 - [PaginatedRingGroupListResponse](docs/PaginatedRingGroupListResponse.md)
 - [PaginatedScheduleListResponse](docs/PaginatedScheduleListResponse.md)
 - [PaginatedSeatListResponse](docs/PaginatedSeatListResponse.md)
 - [PaginatedSipTrunkListResponse](docs/PaginatedSipTrunkListResponse.md)
 - [PaginatedVoicemailBoxListResponse](docs/PaginatedVoicemailBoxListResponse.md)
 - [PaginatedVoicemailBoxListResponseMeta](docs/PaginatedVoicemailBoxListResponseMeta.md)
 - [PaginationLinks](docs/PaginationLinks.md)
 - [PaginationLinksNext](docs/PaginationLinksNext.md)
 - [PaginationLinksPrev](docs/PaginationLinksPrev.md)
 - [PaymentCore](docs/PaymentCore.md)
 - [PaymentListResponse](docs/PaymentListResponse.md)
 - [PaymentResponse](docs/PaymentResponse.md)
 - [PaymentsComponentsSchemasError](docs/PaymentsComponentsSchemasError.md)
 - [PhoneNumberCore](docs/PhoneNumberCore.md)
 - [PhoneNumberCreateRequest](docs/PhoneNumberCreateRequest.md)
 - [PhoneNumberResponse](docs/PhoneNumberResponse.md)
 - [PhoneNumberResponseAllOfDestination](docs/PhoneNumberResponseAllOfDestination.md)
 - [PhoneNumberResponseAllOfFailOverDestination](docs/PhoneNumberResponseAllOfFailOverDestination.md)
 - [PhoneNumberUpdateRequest](docs/PhoneNumberUpdateRequest.md)
 - [PlanCore](docs/PlanCore.md)
 - [PlanResponse](docs/PlanResponse.md)
 - [PlanResponseAllOfPackages](docs/PlanResponseAllOfPackages.md)
 - [PlansComponentsSchemasError](docs/PlansComponentsSchemasError.md)
 - [RevokeRequest](docs/RevokeRequest.md)
 - [RingGroupCore](docs/RingGroupCore.md)
 - [RingGroupCreateRequest](docs/RingGroupCreateRequest.md)
 - [RingGroupResponse](docs/RingGroupResponse.md)
 - [RingGroupUpdateRequest](docs/RingGroupUpdateRequest.md)
 - [ScheduleAttributes](docs/ScheduleAttributes.md)
 - [ScheduleComponentsSchemasError](docs/ScheduleComponentsSchemasError.md)
 - [ScheduleCreateRequest](docs/ScheduleCreateRequest.md)
 - [ScheduleCreateRequestData](docs/ScheduleCreateRequestData.md)
 - [ScheduleResponse](docs/ScheduleResponse.md)
 - [ScheduleResponseData](docs/ScheduleResponseData.md)
 - [ScheduleResponseDataAttributes](docs/ScheduleResponseDataAttributes.md)
 - [ScheduleUpdateRequest](docs/ScheduleUpdateRequest.md)
 - [ScheduleUpdateRequestData](docs/ScheduleUpdateRequestData.md)
 - [ScheduleUpdateRequestDataAttributes](docs/ScheduleUpdateRequestDataAttributes.md)
 - [SchemasCallBlockResponse](docs/SchemasCallBlockResponse.md)
 - [SchemasCallBlockResponseData](docs/SchemasCallBlockResponseData.md)
 - [SchemasCallBlockResponseDataAttributes](docs/SchemasCallBlockResponseDataAttributes.md)
 - [SchemasDeviceCore](docs/SchemasDeviceCore.md)
 - [SchemasError](docs/SchemasError.md)
 - [SchemasLink](docs/SchemasLink.md)
 - [SchemasPhoneNumberCore](docs/SchemasPhoneNumberCore.md)
 - [SchemasPhoneNumberResponse](docs/SchemasPhoneNumberResponse.md)
 - [SchemasSiteDestination](docs/SchemasSiteDestination.md)
 - [SeatCore](docs/SeatCore.md)
 - [SeatCreateRequest](docs/SeatCreateRequest.md)
 - [SeatResponse](docs/SeatResponse.md)
 - [SeatUpdateRequest](docs/SeatUpdateRequest.md)
 - [SignUpComponentsSchemasError](docs/SignUpComponentsSchemasError.md)
 - [SignUpComponentsSchemasLink](docs/SignUpComponentsSchemasLink.md)
 - [SipTrunkCore](docs/SipTrunkCore.md)
 - [SipTrunkCreateRequest](docs/SipTrunkCreateRequest.md)
 - [SipTrunkResponse](docs/SipTrunkResponse.md)
 - [SipTrunkResponseWithPassword](docs/SipTrunkResponseWithPassword.md)
 - [SipTrunkResponseWithPasswordAllOfFailOverDestination](docs/SipTrunkResponseWithPasswordAllOfFailOverDestination.md)
 - [SipTrunkUpdateRequest](docs/SipTrunkUpdateRequest.md)
 - [SiteCore](docs/SiteCore.md)
 - [SiteCreateRequest](docs/SiteCreateRequest.md)
 - [SiteDestination](docs/SiteDestination.md)
 - [SiteListResponse](docs/SiteListResponse.md)
 - [SiteResponse](docs/SiteResponse.md)
 - [SiteUpdateRequest](docs/SiteUpdateRequest.md)
 - [SitesComponentsSchemasError](docs/SitesComponentsSchemasError.md)
 - [StatementCore](docs/StatementCore.md)
 - [StatementListResponse](docs/StatementListResponse.md)
 - [StatementResponse](docs/StatementResponse.md)
 - [StatementsComponentsSchemasError](docs/StatementsComponentsSchemasError.md)
 - [SwitchableFeature](docs/SwitchableFeature.md)
 - [TemplateCore](docs/TemplateCore.md)
 - [TemplateCreateRequest](docs/TemplateCreateRequest.md)
 - [TemplateFeature](docs/TemplateFeature.md)
 - [TemplateFeatureAttribute](docs/TemplateFeatureAttribute.md)
 - [TemplateListResponse](docs/TemplateListResponse.md)
 - [TemplateResponse](docs/TemplateResponse.md)
 - [TemplateUpdateRequest](docs/TemplateUpdateRequest.md)
 - [TemplatesComponentsSchemasError](docs/TemplatesComponentsSchemasError.md)
 - [ThinClient](docs/ThinClient.md)
 - [ThinClientListResponse](docs/ThinClientListResponse.md)
 - [ThinClientsComponentsSchemasError](docs/ThinClientsComponentsSchemasError.md)
 - [TimezoneListResponse](docs/TimezoneListResponse.md)
 - [TimezonesComponentsSchemasError](docs/TimezonesComponentsSchemasError.md)
 - [TokenRequest](docs/TokenRequest.md)
 - [TokenResponse](docs/TokenResponse.md)
 - [TransferComponentsSchemasError](docs/TransferComponentsSchemasError.md)
 - [TransferComponentsSchemasError2](docs/TransferComponentsSchemasError2.md)
 - [TransferSipTrunkRequest](docs/TransferSipTrunkRequest.md)
 - [TransferSipTrunkRequestData](docs/TransferSipTrunkRequestData.md)
 - [TransferSipTrunkRequestDataAttributes](docs/TransferSipTrunkRequestDataAttributes.md)
 - [UserCore](docs/UserCore.md)
 - [UserCreateRequest](docs/UserCreateRequest.md)
 - [UserListResponse](docs/UserListResponse.md)
 - [UserResponse](docs/UserResponse.md)
 - [UserSummary](docs/UserSummary.md)
 - [UserUpdateRequest](docs/UserUpdateRequest.md)
 - [UsersComponentsSchemasError](docs/UsersComponentsSchemasError.md)
 - [VoicemailBoxAttributes](docs/VoicemailBoxAttributes.md)
 - [VoicemailBoxCreateRequestData](docs/VoicemailBoxCreateRequestData.md)
 - [VoicemailBoxResponseData](docs/VoicemailBoxResponseData.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="oAuth2"></a>
### oAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **read**: Read access to API resources
 - **write**: Write access to API resources
 - **admin**: Administrative access


## Author

support@ringer.tel


